@@ -36,12 +36,13 @@
 
 #include <libxfce4util/libxfce4util.h>
 
-#include <parole/parole-file.h>
+#include <src/misc/parole-file.h>
 
 #include "interfaces/playlist_ui.h"
 #include "interfaces/save-playlist_ui.h"
 
 #include "parole-builder.h"
+#include "parole-player.h"
 #include "parole-medialist.h"
 #include "parole-mediachooser.h"
 #include "parole-open-location.h"
@@ -55,7 +56,7 @@
 
 #include "common/parole-common.h"
 
-#define PAROLE_AUTO_SAVED_PLAYLIST 	"xfce4/parole/auto-saved-playlist.m3u"
+#define PAROLE_AUTO_SAVED_PLAYLIST 	"xfce4/src/misc/auto-saved-playlist.m3u"
 
 typedef struct
 {
@@ -99,21 +100,21 @@ static void	parole_media_list_clear_list 	  (ParoleMediaList *list);
 /*
  * Callbacks for GtkBuilder
  */
-void		parole_media_list_media_up_clicked_cb 	(GtkButton *button, 
-							 ParoleMediaList *list);
-							 
-void		parole_media_list_media_down_clicked_cb (GtkButton *button, 
-							 ParoleMediaList *list);
-
-void		parole_media_list_save_cb		(GtkButton *button,
-						         ParoleMediaList *list);
-							 
 void		parole_media_list_add_clicked_cb 	(GtkButton *button, 
 							 ParoleMediaList *list);
 							 
 void		parole_media_list_remove_clicked_cb 	(GtkButton *button, 
 							 ParoleMediaList *list);
 
+void		parole_media_list_clear_clicked_cb 	(GtkButton *button, 
+							 ParoleMediaList *list);
+
+void		parole_media_list_repeat_toggled_cb	(GtkToggleButton *button,
+							 ParoleMediaList *list);
+
+void		parole_media_list_shuffle_toggled_cb	(GtkToggleButton *button,
+							 ParoleMediaList *list);
+
 void		parole_media_list_row_activated_cb 	(GtkTreeView *view, 
 							 GtkTreePath *path,
 							 GtkTreeViewColumn *col,
@@ -167,11 +168,12 @@ struct ParoleMediaListPrivate
     GtkWidget		*box;
     GtkListStore	*store;
     GtkTreeSelection    *sel;
-    
-    GtkWidget		*remove;
-    GtkWidget		*up;
-    GtkWidget		*down;
-    GtkWidget		*save;
+
+    GtkWidget *remove_button;
+    GtkWidget *clear_button;
+    GtkWidget *repeat_button;
+    GtkWidget *shuffle_button;
+	GtkWidget *settings_button;
 };
 
 enum
@@ -179,6 +181,8 @@ enum
     MEDIA_ACTIVATED,
     MEDIA_CURSOR_CHANGED,
     URI_OPENED,
+    SHUFFLE_TOGGLED,
+    REPEAT_TOGGLED,
     LAST_SIGNAL
 };
 
@@ -189,10 +193,8 @@ G_DEFINE_TYPE (ParoleMediaList, parole_media_list, GTK_TYPE_VBOX)
 static void
 parole_media_list_set_widget_sensitive (ParoleMediaList *list, gboolean sensitive)
 {
-    gtk_widget_set_sensitive (GTK_WIDGET (list->priv->up), sensitive);
-    gtk_widget_set_sensitive (GTK_WIDGET (list->priv->remove), sensitive);
-    gtk_widget_set_sensitive (GTK_WIDGET (list->priv->down), sensitive);
-    gtk_widget_set_sensitive (GTK_WIDGET (list->priv->save), sensitive);
+    gtk_widget_set_sensitive (GTK_WIDGET (list->priv->remove_button), sensitive);
+    gtk_widget_set_sensitive (GTK_WIDGET (list->priv->clear_button), sensitive);
 }
 
 /**
@@ -249,10 +251,8 @@ parole_media_list_add (ParoleMediaList *list, ParoleFile *file, gboolean emit, g
     
     if ( nch == 1 )
     {
-	gtk_widget_set_sensitive (list->priv->up, FALSE);
-	gtk_widget_set_sensitive (list->priv->down, FALSE);
-	gtk_widget_set_sensitive (list->priv->save, TRUE);
-	gtk_widget_set_sensitive (list->priv->remove, TRUE);
+	gtk_widget_set_sensitive (list->priv->remove_button, TRUE);
+	gtk_widget_set_sensitive (list->priv->clear_button, TRUE);
     }
     else
 	parole_media_list_set_widget_sensitive (list, TRUE);
@@ -435,6 +435,32 @@ parole_media_list_add_clicked_cb (GtkButton *button, ParoleMediaList *list)
     parole_media_list_open_internal (list);
 }
 
+void 
+parole_media_list_clear_clicked_cb (GtkButton *button, ParoleMediaList *list)
+{
+	parole_media_list_clear_list (list);
+}
+
+void
+parole_media_list_repeat_toggled_cb (GtkToggleButton *button, ParoleMediaList *list)
+{
+	gboolean toggled;
+    
+    toggled = gtk_toggle_button_get_active (button);
+    
+    g_signal_emit (G_OBJECT (list), signals [REPEAT_TOGGLED], 0, toggled);
+}
+
+void
+parole_media_list_shuffle_toggled_cb (GtkToggleButton *button, ParoleMediaList *list)
+{
+	gboolean toggled;
+    
+    toggled = gtk_toggle_button_get_active (button);
+    
+    g_signal_emit (G_OBJECT (list), signals [SHUFFLE_TOGGLED], 0, toggled);
+}
+
 void parole_media_list_close_save_dialog_cb (GtkButton *button, ParolePlaylistSave *data)
 {
     gtk_widget_destroy (GTK_WIDGET (data->chooser));
@@ -837,11 +863,6 @@ parole_media_list_remove_clicked_cb (GtkButton *button, ParoleMediaList *list)
 	 */
 	g_signal_emit (G_OBJECT (list), signals [MEDIA_CURSOR_CHANGED], 0, FALSE);
     }
-    else if ( nch == 1 )
-    {
-	gtk_widget_set_sensitive (list->priv->up, FALSE);
-	gtk_widget_set_sensitive (list->priv->down, FALSE);
-    }
 }
 
 /**
@@ -919,40 +940,6 @@ parole_media_list_move_many_down (GList *path_list, GtkTreeModel *model)
     g_list_free (row_list);
 }
 
-/**
- * parole_media_list_media_down_clicked_cb:
- * 
- * 
- **/
-void
-parole_media_list_media_down_clicked_cb (GtkButton *button, ParoleMediaList *list)
-{
-    GtkTreeIter iter;
-    GList *path_list = NULL;
-    GtkTreeModel *model;
-    guint len;
-    
-    path_list = gtk_tree_selection_get_selected_rows (list->priv->sel, &model);
-
-    len = g_list_length (path_list);
-
-    if ( len == 1 )
-    {
-	GtkTreePath *path;
-	path = g_list_nth_data (path_list, 0);
-	if ( G_LIKELY (gtk_tree_model_get_iter (model, &iter, path)) )
-	    parole_media_list_move_one_down (list->priv->store, &iter);
-    }
-    else
-    {
-	parole_media_list_move_many_down (path_list, model);
-    }
-    
-    g_list_foreach (path_list, (GFunc) gtk_tree_path_free, NULL);
-    g_list_free (path_list);
-}
-
-
 /**
  * parole_media_list_move_on_up:
  * 
@@ -1031,39 +1018,6 @@ parole_media_list_move_many_up (GList *path_list, GtkTreeModel *model)
     g_list_free (row_list);
 }
 
-/**
- * parole_media_list_media_up_clicked_cb:
- * 
- * 
- **/
-void
-parole_media_list_media_up_clicked_cb (GtkButton *button, ParoleMediaList *list)
-{
-    GtkTreeIter iter;
-    GList *path_list = NULL;
-    GtkTreeModel *model;
-    guint len;
-    
-    path_list = gtk_tree_selection_get_selected_rows (list->priv->sel, &model);
-
-    len = g_list_length (path_list);
-
-    if ( len == 1 )
-    {
-	GtkTreePath *path;
-	path = g_list_nth_data (path_list, 0);
-	if ( G_LIKELY (gtk_tree_model_get_iter (model, &iter, path)) )
-	    parole_media_list_move_one_up (list->priv->store, &iter);
-    }
-    else
-    {
-	parole_media_list_move_many_up (path_list, model);
-    }
-    
-    g_list_foreach (path_list, (GFunc) gtk_tree_path_free, NULL);
-    g_list_free (path_list);
-}
-
 /**
  * parole_media_list_row_activated_cb:
  * 
@@ -1186,44 +1140,63 @@ static void
 replace_list_activated_cb (GtkWidget *mi, ParoleConf *conf)
 {
     g_object_set (G_OBJECT (conf),
-		  "replace-playlist", gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (mi)),
+		  "replace-playlist", gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (mi)),
 		  NULL);
-		
 }
 
 static void
 play_opened_files_activated_cb (GtkWidget *mi, ParoleConf *conf)
 {
     g_object_set (G_OBJECT (conf),
-		  "play-opened-files", gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (mi)),
+		  "play-opened-files", gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (mi)),
 		  NULL);
 		
 }
 
 static void
-save_list_activated_cb (GtkWidget *mi)
-{
-    gboolean active;
-    
-    active = gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (mi));
-    
-    parole_rc_write_entry_bool ("SAVE_LIST_ON_EXIT", PAROLE_RC_GROUP_GENERAL, active);
-}
-
-static void
-repeat_activated_cb (GtkWidget *mi, ParoleConf *conf)
+remember_playlist_activated_cb (GtkWidget *mi, ParoleConf *conf)
 {
     g_object_set (G_OBJECT (conf),
-		  "repeat", gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (mi)),
+		  "remember-playlist", gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (mi)),
 		  NULL);
 }
 
 static void
-shuffle_activated_cb (GtkWidget *mi, ParoleConf *conf)
+repeat_activated_cb (GtkWidget *mi, ParoleMediaList *list)
 {
-    g_object_set (G_OBJECT (conf),
-		  "shuffle", gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (mi)),
-		  NULL);
+	gboolean active = gtk_check_menu_item_get_active( GTK_CHECK_MENU_ITEM( mi ) );
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON( list->priv->repeat_button ), active);
+}
+
+static void
+shuffle_activated_cb (GtkWidget *mi, ParoleMediaList *list)
+{
+	gboolean active = gtk_check_menu_item_get_active( GTK_CHECK_MENU_ITEM( mi ) );
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON( list->priv->shuffle_button ), active);
+}
+
+void
+parole_media_list_menu_pos (GtkMenu *menu, gint *px, gint *py, gpointer data)
+{
+	gint x, y;
+	GtkAllocation widget_allocation, menu_allocation;
+	GtkWidget *widget = gtk_menu_get_attach_widget( menu );
+	
+	gtk_widget_get_allocation( widget, &widget_allocation );
+	gtk_widget_get_allocation( GTK_WIDGET(menu), &menu_allocation );
+	
+	//g_print("h = %i", requisition.height);
+	GdkWindow *window = gtk_widget_get_window( widget );
+	gdk_window_get_position( window, &x, &y );
+	
+	px += x + widget_allocation.x - menu_allocation.width + widget_allocation.width;
+	py += y + widget_allocation.y + widget_allocation.height;
+}
+
+static void
+parole_media_list_hide_menu (GtkWidget *widget)
+{
+	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( widget ), FALSE );
 }
 
 static void
@@ -1242,122 +1215,147 @@ parole_media_list_destroy_menu (GtkWidget *menu)
 }
 
 static void
-parole_media_list_show_menu (ParoleMediaList *list, GdkEventButton *ev)
+menu_detach( GtkMenu *menu )
 {
-    GtkWidget *menu, *mi;
-    gboolean val;
-    guint button = ev->button; 
-    guint activate_time = ev->time;
+	//gtk_menu_detach (menu);
+}
 
-    menu = gtk_menu_new ();
+static void
+parole_media_list_show_button_menu (GtkToggleButton *button, ParoleMediaList *list)
+{
+	gboolean toggled = gtk_toggle_button_get_active( button );
+	if (!toggled)
+	return;
 
-    parole_media_list_add_open_containing_folder (list, menu, (gint)ev->x, (gint)ev->y);
+	gboolean val;
     
+    GtkBuilder *builder;
+    
+    builder = parole_builder_new_from_string (playlist_ui, playlist_ui_length);
+    
+    GtkMenu *menu = GTK_MENU (gtk_builder_get_object (builder, "playlist-menu"));
+    GtkCheckMenuItem *repeat_menu = GTK_CHECK_MENU_ITEM (gtk_builder_get_object (builder, "menu-repeat"));
+    GtkCheckMenuItem *shuffle_menu = GTK_CHECK_MENU_ITEM (gtk_builder_get_object (builder, "menu-shuffle"));
+    GtkCheckMenuItem *replace = GTK_CHECK_MENU_ITEM (gtk_builder_get_object (builder, "menu-replace"));
+    GtkCheckMenuItem *play_opened = GTK_CHECK_MENU_ITEM (gtk_builder_get_object (builder, "menu-play-opened"));
+    GtkCheckMenuItem *remember = GTK_CHECK_MENU_ITEM (gtk_builder_get_object (builder, "menu-remember"));
+    GtkMenuItem *clear = GTK_MENU_ITEM (gtk_builder_get_object (builder, "menu-clear"));
+    
+    gtk_menu_attach_to_widget( GTK_MENU(menu), list->priv->settings_button, (GtkMenuDetachFunc) menu_detach );
 
-    /**
-     * Repeat playing.
-     **/
     g_object_get (G_OBJECT (list->priv->conf),
 		  "repeat", &val,
 		  NULL);
+    gtk_check_menu_item_set_active (repeat_menu, val);
+    g_signal_connect (repeat_menu, "activate",
+                      G_CALLBACK (repeat_activated_cb), list);
 
-    mi = gtk_check_menu_item_new_with_label (_("Repeat"));
-    gtk_widget_set_sensitive (mi, TRUE);
-    gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (mi), val);
-    g_signal_connect (mi, "activate",
-                      G_CALLBACK (repeat_activated_cb), list->priv->conf);
-			      
-    gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
-    gtk_widget_show (mi);
-
-    /**
-     * Shuffle playing.
-     **/
     g_object_get (G_OBJECT (list->priv->conf),
 		  "shuffle", &val,
 		  NULL);
 
-    mi = gtk_check_menu_item_new_with_label (_("Shuffle"));
-    gtk_widget_set_sensitive (mi, TRUE);
-    gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (mi), val);
-    g_signal_connect (mi, "activate",
-                      G_CALLBACK (shuffle_activated_cb), list->priv->conf);
+    gtk_check_menu_item_set_active (shuffle_menu, val);
+    g_signal_connect (shuffle_menu, "activate",
+                      G_CALLBACK (shuffle_activated_cb), list);
 			      
-    gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
-    gtk_widget_show (mi);
-
-    /**
-     * Separator
-     **/
-    mi = gtk_separator_menu_item_new ();
-    gtk_widget_show (mi);
-    gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
-
-    /**
-     * replace playlist
-     **/
     g_object_get (G_OBJECT (list->priv->conf),
 		  "replace-playlist", &val,
 		  NULL);
 
-    mi = gtk_check_menu_item_new_with_label (_("Replace playlist when opening files"));
-    gtk_widget_set_sensitive (mi, TRUE);
-    gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (mi), val);
-    g_signal_connect (mi, "activate",
+    gtk_check_menu_item_set_active (replace, val);
+    g_signal_connect (replace, "activate",
                       G_CALLBACK (replace_list_activated_cb), list->priv->conf);
 			      
-    gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
-    gtk_widget_show (mi);
-    
-    /**
-     * Play when files are open.
-     **/
-    
     g_object_get (G_OBJECT (list->priv->conf),
 		  "play-opened-files", &val,
 		  NULL);
-    mi = gtk_check_menu_item_new_with_label (_("Play opened files"));
-    gtk_widget_set_sensitive (mi, TRUE);
-    gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (mi), val);
-    g_signal_connect (mi, "activate",
+    gtk_check_menu_item_set_active (play_opened, val);
+    g_signal_connect (play_opened, "activate",
                       G_CALLBACK (play_opened_files_activated_cb), list->priv->conf);
-			      
-    gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
-    gtk_widget_show (mi);
-    
-    /**
-     * Remember media list entries
-     **/
-    mi = gtk_check_menu_item_new_with_label (_("Remember playlist"));
-    gtk_widget_set_sensitive (mi, TRUE);
-    gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (mi),
-				    parole_rc_read_entry_bool ("SAVE_LIST_ON_EXIT", 
-							        PAROLE_RC_GROUP_GENERAL, 
-								FALSE));
-    g_signal_connect (mi, "activate",
-                      G_CALLBACK (save_list_activated_cb), NULL);
-			      
-    gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
-    
-    gtk_widget_show (mi);
-    
-    /**
-     * Separator
-     **/
-    mi = gtk_separator_menu_item_new ();
-    gtk_widget_show (mi);
-    gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
-    
-    
-    /* Clear */
-    mi = gtk_image_menu_item_new_from_stock (GTK_STOCK_CLEAR, NULL);
-    gtk_widget_set_sensitive (mi, TRUE);
-    gtk_widget_show (mi);
-    g_signal_connect_swapped (mi, "activate",
+
+    g_object_get (G_OBJECT (list->priv->conf),
+		  "remember-playlist", &val,
+		  NULL);
+    gtk_check_menu_item_set_active (remember, val);
+    g_signal_connect (remember, "activate",
+                      G_CALLBACK (remember_playlist_activated_cb), list->priv->conf);
+
+    g_signal_connect_swapped (clear, "activate",
                               G_CALLBACK (parole_media_list_clear_list), list);
-			      
-    gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
+
+    g_signal_connect_swapped (menu, "selection-done",
+                              G_CALLBACK (parole_media_list_destroy_menu), menu);
+                              
+	g_signal_connect_swapped (menu, "destroy",
+                              G_CALLBACK (parole_media_list_hide_menu), list->priv->settings_button);
     
+    gtk_menu_popup (GTK_MENU (menu), 
+                    NULL, NULL,
+                    (GtkMenuPositionFunc) parole_media_list_menu_pos, NULL,
+                    3, gtk_get_current_event_time ());
+}
+
+static void
+parole_media_list_show_menu (ParoleMediaList *list, GdkEventButton *ev)
+{
+    gboolean val;
+    guint button = ev->button; 
+    guint activate_time = ev->time;
+    
+    GtkBuilder *builder;
+    
+    builder = parole_builder_new_from_string (playlist_ui, playlist_ui_length);
+    
+    GtkMenu *menu = GTK_MENU (gtk_builder_get_object (builder, "playlist-menu"));
+    GtkCheckMenuItem *repeat_menu = GTK_CHECK_MENU_ITEM (gtk_builder_get_object (builder, "menu-repeat"));
+    GtkCheckMenuItem *shuffle_menu = GTK_CHECK_MENU_ITEM (gtk_builder_get_object (builder, "menu-shuffle"));
+    GtkCheckMenuItem *replace = GTK_CHECK_MENU_ITEM (gtk_builder_get_object (builder, "menu-replace"));
+    GtkCheckMenuItem *play_opened = GTK_CHECK_MENU_ITEM (gtk_builder_get_object (builder, "menu-play-opened"));
+    GtkCheckMenuItem *remember = GTK_CHECK_MENU_ITEM (gtk_builder_get_object (builder, "menu-remember"));
+    GtkMenuItem *clear = GTK_MENU_ITEM (gtk_builder_get_object (builder, "menu-clear"));
+    
+    parole_media_list_add_open_containing_folder (list, GTK_WIDGET(menu), (gint)ev->x, (gint)ev->y);
+
+    g_object_get (G_OBJECT (list->priv->conf),
+		  "repeat", &val,
+		  NULL);
+    gtk_check_menu_item_set_active (repeat_menu, val);
+    g_signal_connect (repeat_menu, "activate",
+                      G_CALLBACK (repeat_activated_cb), list);
+
+    g_object_get (G_OBJECT (list->priv->conf),
+		  "shuffle", &val,
+		  NULL);
+
+    gtk_check_menu_item_set_active (shuffle_menu, val);
+    g_signal_connect (shuffle_menu, "activate",
+                      G_CALLBACK (shuffle_activated_cb), list);
+			      
+    g_object_get (G_OBJECT (list->priv->conf),
+		  "replace-playlist", &val,
+		  NULL);
+
+    gtk_check_menu_item_set_active (replace, val);
+    g_signal_connect (replace, "activate",
+                      G_CALLBACK (replace_list_activated_cb), list->priv->conf);
+			      
+    g_object_get (G_OBJECT (list->priv->conf),
+		  "play-opened-files", &val,
+		  NULL);
+    gtk_check_menu_item_set_active (play_opened, val);
+    g_signal_connect (play_opened, "activate",
+                      G_CALLBACK (play_opened_files_activated_cb), list->priv->conf);
+
+    g_object_get (G_OBJECT (list->priv->conf),
+		  "remember-playlist", &val,
+		  NULL);
+    gtk_check_menu_item_set_active (remember, val);
+    g_signal_connect (remember, "activate",
+                      G_CALLBACK (remember_playlist_activated_cb), list->priv->conf);
+
+    g_signal_connect_swapped (clear, "activate",
+                              G_CALLBACK (parole_media_list_clear_list), list);
+
     g_signal_connect_swapped (menu, "selection-done",
                               G_CALLBACK (parole_media_list_destroy_menu), menu);
     
@@ -1448,6 +1446,24 @@ parole_media_list_class_init (ParoleMediaListClass *klass)
                       NULL, NULL,
                       g_cclosure_marshal_VOID__STRING,
                       G_TYPE_NONE, 1, G_TYPE_STRING);
+                      
+	signals[SHUFFLE_TOGGLED] = 
+        g_signal_new ("shuffle-toggled",
+                      PAROLE_TYPE_MEDIA_LIST,
+                      G_SIGNAL_RUN_LAST,
+                      G_STRUCT_OFFSET (ParoleMediaListClass, shuffle_toggled),
+                      NULL, NULL,
+                      g_cclosure_marshal_VOID__BOOLEAN,
+                      G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
+                      
+	signals[REPEAT_TOGGLED] = 
+        g_signal_new ("repeat-toggled",
+                      PAROLE_TYPE_MEDIA_LIST,
+                      G_SIGNAL_RUN_LAST,
+                      G_STRUCT_OFFSET (ParoleMediaListClass, repeat_toggled),
+                      NULL, NULL,
+                      g_cclosure_marshal_VOID__BOOLEAN,
+                      G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
 
     g_type_class_add_private (klass, sizeof (ParoleMediaListPrivate));
     
@@ -1533,14 +1549,18 @@ parole_media_list_init (ParoleMediaList *list)
     
     parole_media_list_setup_view (list);
     
-    gtk_builder_connect_signals (builder, list);
-
     gtk_box_pack_start (GTK_BOX (list), box, TRUE, TRUE, 0);
+    
+    list->priv->remove_button = GTK_WIDGET (gtk_builder_get_object (builder, "remove-media"));
+    list->priv->clear_button = GTK_WIDGET (gtk_builder_get_object (builder, "clear-media"));
+    list->priv->repeat_button = GTK_WIDGET (gtk_builder_get_object (builder, "repeat-media"));
+    list->priv->shuffle_button = GTK_WIDGET (gtk_builder_get_object (builder, "shuffle-media"));
+    list->priv->settings_button = GTK_WIDGET (gtk_builder_get_object (builder, "settings"));
+    
+    g_signal_connect (GTK_TOGGLE_BUTTON(list->priv->settings_button), "toggled",
+		      G_CALLBACK (parole_media_list_show_button_menu), list);
 
-    list->priv->up = GTK_WIDGET (gtk_builder_get_object (builder, "media-up"));
-    list->priv->down = GTK_WIDGET (gtk_builder_get_object (builder, "media-down"));
-    list->priv->remove = GTK_WIDGET (gtk_builder_get_object (builder, "remove-media"));
-    list->priv->save = GTK_WIDGET (gtk_builder_get_object (builder, "save-playlist"));
+    gtk_builder_connect_signals (builder, list);
 
     g_object_unref (builder);
     
@@ -1835,7 +1855,7 @@ void parole_media_list_open_location (ParoleMediaList *list)
     parole_media_list_open_location_internal (list);
 }
 
-gboolean parole_media_list_add_files (ParoleMediaList *list, gchar **filenames)
+gboolean parole_media_list_add_files (ParoleMediaList *list, gchar **filenames, gboolean enqueue)
 {
     guint i;
     guint added = 0;
@@ -1845,7 +1865,7 @@ gboolean parole_media_list_add_files (ParoleMediaList *list, gchar **filenames)
 	/*
 	 * File on disk?
 	 */
-	if ( g_file_test (filenames[i], G_FILE_TEST_EXISTS ) )
+	if ( !enqueue && g_file_test (filenames[i], G_FILE_TEST_EXISTS ) )
 	{
 	    added += parole_media_list_add_by_path (list, filenames[i], i == 0 ? TRUE : FALSE);
 	}
@@ -1854,7 +1874,10 @@ gboolean parole_media_list_add_files (ParoleMediaList *list, gchar **filenames)
 	    ParoleFile *file;
 	    TRACE ("File=%s", filenames[i]);
 	    file = parole_file_new (filenames[i]);
-	    parole_media_list_add (list, file, i == 0 ? TRUE : FALSE, i == 0 ? TRUE : FALSE);
+		if (enqueue) {
+			parole_media_list_add (list, file, FALSE, FALSE);}
+		else
+			parole_media_list_add (list, file, i == 0 ? TRUE : FALSE, i == 0 ? TRUE : FALSE);
 	    added++;
 	}
     }
@@ -1892,7 +1915,7 @@ void parole_media_list_save_list (ParoleMediaList *list)
 }
 
 static gboolean	 parole_media_list_dbus_add_files (ParoleMediaList *list,
-					           gchar **in_files,
+					           gchar **in_files, gboolean enqueue,
 						   GError **error);
 
 #include "org.parole.media.list.h"
@@ -1916,12 +1939,12 @@ parole_media_list_dbus_init (ParoleMediaList *list)
 }
 
 static gboolean	 parole_media_list_dbus_add_files (ParoleMediaList *list,
-						   gchar **in_files,
+						   gchar **in_files, gboolean enqueue,
 						   GError **error)
 {
     TRACE ("Adding files for DBus request");
     gtk_window_present (GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (list))));
-    parole_media_list_add_files (list, in_files);
+    parole_media_list_add_files (list, in_files, enqueue);
     
     return TRUE;
 }
@@ -1931,3 +1954,31 @@ void parole_media_list_grab_focus (ParoleMediaList *list)
     if (GTK_WIDGET_VISIBLE (list->priv->view) )
 	gtk_widget_grab_focus (list->priv->view);
 }
+
+void 
+parole_media_list_set_repeat_toggled (ParoleMediaList *list,
+									  gboolean repeat_toggled)
+{
+	gboolean toggled;
+    
+    toggled = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (list->priv->repeat_button));
+    
+    if (toggled != repeat_toggled)
+    {
+    	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON (list->priv->repeat_button), repeat_toggled );
+	}
+}
+																
+void 
+parole_media_list_set_shuffle_toggled (ParoleMediaList *list,
+									  gboolean shuffle_toggled)
+{
+	gboolean toggled;
+    
+    toggled = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (list->priv->shuffle_button));
+    
+    if (toggled != shuffle_toggled)
+    {
+    	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON (list->priv->shuffle_button), shuffle_toggled );
+	}
+}
